/* 
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *  
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *  
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Ben Goodger (03/11/99)
 */

//var bundle = srGetStrBundle("chrome://communicator/locale/profile/newProfile1_2.properties");
//var detect = false;

// the getting procedure is unique to each page, since each page can different
// types of elements (not necessarily form elements). So each page must provide
// its own GetFields function
function GetFields()
{

  var emailaddr = "dummy"
  var rv = { 
    emailaddr: { id: "emailaddr",      value: emailaddr       },

  }
  return rv; 
  
}

// the setting procedure is unique to each page, and as such each page
// must provide its own SetFields function
function SetFields(element,set)
{
  element = document.getElementById(element);
  //dump("In SetFields(" + element + "," + set + ");\n");
 if(element.id == "emailaddr")
    element.value = set;
} 

function setNext(thelabel){
	parent.wizardManager.wizardMap[parent.wizardManager.currentPageTag].next=thelabel
} 


